# Google Cloud Secrets Manager

This module will create a Google Secret Manager secret and associated secret version with a passed
content.

This module conforms to the [terraform standard module
structure](https://www.terraform.io/docs/modules/create.html#standard-module-structure).

The id, the version and the url for the secret created are available from the project
[outputs](outputs.tf). Configuration variables are documented in [variables.tf](variables.tf).

## Examples

### A basic secret and secret version

The following example creates a secret with the ID `test-secret` and a corresponding secret version
containing the data `super-secret-data`.

```tf
module "secret" {
  source      = "git::https://gitlab.developers.cam.ac.uk/uis/devops/infra/terraform/gcp-secret-manager.git?ref=v3"
  project     = local.project
  region      = "europe-west1"
  secret_id   = "test-secret"
  secret_data = "super-secret-data"
}
```

### A basic secret without a secret version

The following example creates a secret with the ID `test-secret` but a corresponding secret version
is not created as the `secret_data` variable has not been set. This is useful in situations where
you want to manage the secret object in Terraform but do not want Terraform to manage the secret
data.

```tf
module "secret" {
  source      = "git::https://gitlab.developers.cam.ac.uk/uis/devops/infra/terraform/gcp-secret-manager.git?ref=v3"
  project     = local.project
  region      = "europe-west1"
  secret_id   = "test-secret"
}
```

### Configure secret accessor IAM bindings

The following example grants the `my_secret_accessor` service account the
`roles/secretmanager.secretAccessor` role on the newly create secret object.

```tf
resource "google_service_account" "secret_accessor" {
    account_id  = "my_secret_accessor"
    description = "My secret accessor service account"
    project     = local.project
}

module "secret" {
  source           = "git::https://gitlab.developers.cam.ac.uk/uis/devops/infra/terraform/gcp-secret-manager.git?ref=v3"
  project          = local.project
  region           = "europe-west1"
  secret_id        = "test-secret"
  secret_accessors = {
    arbitrary_key_name = "serviceAccount:${google_service_account.secret_accessor.email}"
  }
}
```

### Further examples

The [examples](examples/) directory contains examples of use. A basic usage
example is available in [examples/root-example](examples/root-example/).

## Versioning

The `master` branch contains the tip of development and corresponds to the `v3`
branch. The `v2` branch will maintain source compatibility with the initial
release.